pub struct QLThumbnailGenerator { /* private fields */ }QLThumbnailGenerator only.Expand description
Implementations
Sourceimpl QLThumbnailGenerator
impl QLThumbnailGenerator
Sourcepub unsafe fn generateBestRepresentationForRequest_completionHandler(
&self,
request: &QLThumbnailGenerationRequest,
completion_handler: &DynBlock<dyn Fn(*mut QLThumbnailRepresentation, *mut NSError)>,
)
Available on crate features QLThumbnailGenerationRequest and QLThumbnailRepresentation and block2 only.
pub unsafe fn generateBestRepresentationForRequest_completionHandler( &self, request: &QLThumbnailGenerationRequest, completion_handler: &DynBlock<dyn Fn(*mut QLThumbnailRepresentation, *mut NSError)>, )
QLThumbnailGenerationRequest and QLThumbnailRepresentation and block2 only.Parameter completionHandler: Always called when the thumbnail generation is over.
The thumbnail passed to this handler is the most representative version of the thumbnail that was successfully generated (if any).
If set, the error contains information about the issue that occurred while trying to generate the thumbnail.
QLThumbnail error codes can be found in
<QuickLookThumbnailing
/QLThumbnailErrors.h>.
Sourcepub unsafe fn generateRepresentationsForRequest_updateHandler(
&self,
request: &QLThumbnailGenerationRequest,
update_handler: Option<&DynBlock<dyn Fn(*mut QLThumbnailRepresentation, QLThumbnailRepresentationType, *mut NSError)>>,
)
Available on crate features QLThumbnailGenerationRequest and QLThumbnailRepresentation and block2 only.
pub unsafe fn generateRepresentationsForRequest_updateHandler( &self, request: &QLThumbnailGenerationRequest, update_handler: Option<&DynBlock<dyn Fn(*mut QLThumbnailRepresentation, QLThumbnailRepresentationType, *mut NSError)>>, )
QLThumbnailGenerationRequest and QLThumbnailRepresentation and block2 only.Parameter updateHandler: Called for the successive requested representations of a thumbnail.
If a representation was not successfully generated, this may be called with a nil representation.
If a requested more representative version was successfully generated before a less representative one, this handler will be called only for the more representative version, skipping the less representative one.
This handler is guaranteed to be called at least once, for the requested most representative version, whether a representation could be successfully generated or not.
If set, the error contains information about the issue that occurred while trying to generate the representation of the given type.
QLThumbnail error codes can be found in
<QuickLookThumbnailing
/QLThumbnailErrors.h>.
Sourcepub unsafe fn cancelRequest(&self, request: &QLThumbnailGenerationRequest)
Available on crate feature QLThumbnailGenerationRequest only.
pub unsafe fn cancelRequest(&self, request: &QLThumbnailGenerationRequest)
QLThumbnailGenerationRequest only.Cancels the given QLThumbnailGenerationRequest.
Parameter request: The request that should be cancelled.
Sourcepub unsafe fn saveBestRepresentationForRequest_toFileAtURL_asContentType_completionHandler(
&self,
request: &QLThumbnailGenerationRequest,
file_url: &NSURL,
content_type: &UTType,
completion_handler: &DynBlock<dyn Fn(*mut NSError)>,
)
Available on crate features QLThumbnailGenerationRequest and block2 and objc2-uniform-type-identifiers only.
pub unsafe fn saveBestRepresentationForRequest_toFileAtURL_asContentType_completionHandler( &self, request: &QLThumbnailGenerationRequest, file_url: &NSURL, content_type: &UTType, completion_handler: &DynBlock<dyn Fn(*mut NSError)>, )
QLThumbnailGenerationRequest and block2 and objc2-uniform-type-identifiers only.Saves a thumbnail for the request on disk at fileURL. The file saved at fileURL has to be deleted when it is not used anymore. This is primarily intended for file provider extensions which need to upload thumbnails and have a small memory limit.
Parameter contentType: An image content type to save the thumbnail as, supported by CGImageDestination, such as UTTypePNG or UTTypeJPEG
Parameter completionHandler: Always called when the thumbnail generation is over. Will contain an error if the thumbnail could not be successfully saved to disk at fileURL.
Sourcepub unsafe fn saveBestRepresentationForRequest_toFileAtURL_withContentType_completionHandler(
&self,
request: &QLThumbnailGenerationRequest,
file_url: &NSURL,
content_type: &NSString,
completion_handler: &DynBlock<dyn Fn(*mut NSError)>,
)
👎DeprecatedAvailable on crate features QLThumbnailGenerationRequest and block2 only.
pub unsafe fn saveBestRepresentationForRequest_toFileAtURL_withContentType_completionHandler( &self, request: &QLThumbnailGenerationRequest, file_url: &NSURL, content_type: &NSString, completion_handler: &DynBlock<dyn Fn(*mut NSError)>, )
QLThumbnailGenerationRequest and block2 only.Saves a thumbnail for the request on disk at fileURL. The file saved at fileURL has to be deleted when it is not used anymore. This is primarily intended for file provider extensions which need to upload thumbnails and have a small memory limit.
Parameter contentType: An image content type to save the thumbnail as, supported by CGImageDestination, such as kUTTypePNG or kUTTypeJPEG
Parameter completionHandler: Always called when the thumbnail generation is over. Will contain an error if the thumbnail could not be successfully saved to disk at fileURL.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for QLThumbnailGenerator
impl AsRef<AnyObject> for QLThumbnailGenerator
Sourceimpl AsRef<NSObject> for QLThumbnailGenerator
impl AsRef<NSObject> for QLThumbnailGenerator
Sourceimpl Borrow<AnyObject> for QLThumbnailGenerator
impl Borrow<AnyObject> for QLThumbnailGenerator
Sourceimpl Borrow<NSObject> for QLThumbnailGenerator
impl Borrow<NSObject> for QLThumbnailGenerator
Sourceimpl ClassType for QLThumbnailGenerator
impl ClassType for QLThumbnailGenerator
Sourceconst NAME: &'static str = "QLThumbnailGenerator"
const NAME: &'static str = "QLThumbnailGenerator"
Sourcetype ThreadKind = <<QLThumbnailGenerator as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<QLThumbnailGenerator as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for QLThumbnailGenerator
impl Debug for QLThumbnailGenerator
Sourceimpl Deref for QLThumbnailGenerator
impl Deref for QLThumbnailGenerator
Sourceimpl Hash for QLThumbnailGenerator
impl Hash for QLThumbnailGenerator
Sourceimpl Message for QLThumbnailGenerator
impl Message for QLThumbnailGenerator
Sourceimpl NSObjectProtocol for QLThumbnailGenerator
impl NSObjectProtocol for QLThumbnailGenerator
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref