pub struct QLThumbnailReply { /* private fields */ }QLThumbnailReply only.Expand description
To provide a thumbnail for a request, you have to return a QLThumbnailReply object.
To provide a thumbnail, you have two options:
- Draw the thumbnail, by providing a QLThumbnailReply created with a drawing block.
- Pass the thumbnail file URL, by providing a QLThumbnailReply created with a file URL.
See also Apple’s documentation
Implementations
Sourceimpl QLThumbnailReply
impl QLThumbnailReply
Sourcepub unsafe fn extensionBadge(&self) -> Retained<NSString>
pub unsafe fn extensionBadge(&self) -> Retained<NSString>
The extensionBadge is a short string identifying the file type used as a badge when producing an icon.
Sourcepub unsafe fn setExtensionBadge(&self, extension_badge: &NSString)
pub unsafe fn setExtensionBadge(&self, extension_badge: &NSString)
Setter for extensionBadge.
This is copied when set.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn replyWithContextSize_drawingBlock(
context_size: CGSize,
drawing_block: &DynBlock<dyn Fn(NonNull<CGContext>) -> Bool>,
) -> Retained<Self>
Available on crate features block2 and objc2-core-foundation and objc2-core-graphics only.
pub unsafe fn replyWithContextSize_drawingBlock( context_size: CGSize, drawing_block: &DynBlock<dyn Fn(NonNull<CGContext>) -> Bool>, ) -> Retained<Self>
block2 and objc2-core-foundation and objc2-core-graphics only.You can create a reply with a drawing block that will draw into a given context with the coordinate system of Core Graphics.
Parameter contextSize: The desired size of the context that will be passed to the drawing block.
It should be as close as possible to the maximumSize of the QLFileThumbnailRequest and it has to be greater than or equal to its minimumSize.
Ideally, at least either contextSize’s width matches maximumSize’s width or contextSize’s height matches maximumSize’s height. The context size will be scaled to QLFileThumbnailRequest’s scale value (if you pass (x, y), the size of the context will be (scale * x, scale * y)).
Parameter drawingBlock: The thumbnail should be drawn into the context passed to this block. It is a context of type CGBitmapContext, set up to be used with the coordinate system of Core Graphics.
Return YES if the thumbnail was successfully drawn into the context. Return NO otherwise.
Sourcepub unsafe fn replyWithContextSize_currentContextDrawingBlock(
context_size: CGSize,
drawing_block: &DynBlock<dyn Fn() -> Bool>,
) -> Retained<Self>
Available on crate features block2 and objc2-core-foundation only.
pub unsafe fn replyWithContextSize_currentContextDrawingBlock( context_size: CGSize, drawing_block: &DynBlock<dyn Fn() -> Bool>, ) -> Retained<Self>
block2 and objc2-core-foundation only.You can create a reply with a drawing block that will draw into the current context with the coordinate system of UIKit or AppKit.
Parameter contextSize: The desired size of the context that will be passed to the drawing block.
It should be as close as possible to the maximumSize of the QLFileThumbnailRequest and it has to be greater than or equal to its minimumSize.
Ideally, at least either contextSize’s width matches maximumSize’s width or contextSize’s height matches maximumSize’s height. The context size will be scaled to QLFileThumbnailRequest’s scale value (if you pass (x, y), the size of the context will be (scale * x, scale * y)).
Parameter drawingBlock: A block that draws the thumbnail into the current context which you can access via UIGraphicsGetCurrentContext() or [NSGraphicsContext currentContext].
It is a context of type CGBitmapContext, set up to be used with the coordinate system of UIKit or AppKit.
Return YES if the thumbnail was successfully drawn into the current context. Return NO otherwise.
Sourcepub unsafe fn replyWithImageFileURL(file_url: &NSURL) -> Retained<Self>
pub unsafe fn replyWithImageFileURL(file_url: &NSURL) -> Retained<Self>
You can create a reply object with a file URL of an image that will be used as the thumbnail. The image will be downscaled to fit the size of the QLFileThumbnailRequest if necessary.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for QLThumbnailReply
impl AsRef<AnyObject> for QLThumbnailReply
Sourceimpl AsRef<NSObject> for QLThumbnailReply
impl AsRef<NSObject> for QLThumbnailReply
Sourceimpl AsRef<QLThumbnailReply> for QLThumbnailReply
impl AsRef<QLThumbnailReply> for QLThumbnailReply
Sourceimpl Borrow<AnyObject> for QLThumbnailReply
impl Borrow<AnyObject> for QLThumbnailReply
Sourceimpl Borrow<NSObject> for QLThumbnailReply
impl Borrow<NSObject> for QLThumbnailReply
Sourceimpl ClassType for QLThumbnailReply
impl ClassType for QLThumbnailReply
Sourceconst NAME: &'static str = "QLThumbnailReply"
const NAME: &'static str = "QLThumbnailReply"
Sourcetype ThreadKind = <<QLThumbnailReply as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<QLThumbnailReply as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for QLThumbnailReply
impl Debug for QLThumbnailReply
Sourceimpl Deref for QLThumbnailReply
impl Deref for QLThumbnailReply
Sourceimpl Hash for QLThumbnailReply
impl Hash for QLThumbnailReply
Sourceimpl Message for QLThumbnailReply
impl Message for QLThumbnailReply
Sourceimpl NSObjectProtocol for QLThumbnailReply
impl NSObjectProtocol for QLThumbnailReply
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref