QLThumbnailGenerationRequest

Struct QLThumbnailGenerationRequest 

pub struct QLThumbnailGenerationRequest { /* private fields */ }
Available on crate feature QLThumbnailGenerationRequest only.
Implementations

Source

impl QLThumbnailGenerationRequest

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new() -> Retained<Self>

pub unsafe fn initWithFileAtURL_size_scale_representationTypes( this: Allocated<Self>, url: &NSURL, size: CGSize, scale: CGFloat, representation_types: QLThumbnailGenerationRequestRepresentationTypes, ) -> Retained<Self>

Available on crate feature objc2-core-foundation only.

Parameter url: The url of the file on disk for which a thumbnail is requested.

Parameter size: The desired size of the thumbnails that should be generated.

Parameter scale: The desired scale of the thumbnails that should be generated. This will usually be the scale of the screen. You can for instance pass a scale different from the one of the screen if you would like to save generated thumbnails to a server to later download them on devices with a different screen scale.

Parameter representationTypes: The desired successive representations of the thumbnail that should be generated when possible.

pub unsafe fn contentType(&self) -> Retained<UTType>

Available on crate feature objc2-uniform-type-identifiers only.

The content type of the file being thumbnailed is used to determine the provider of the thumbnail and the icon styles applied if iconMode is requested. By default the content type is derived from the file extension. Setting this property will override the derived content type. This is useful for files that don’t have meaningful extensions but for which you may already know the content type.

pub unsafe fn setContentType(&self, content_type: Option<&UTType>)

Available on crate feature objc2-uniform-type-identifiers only.

Setter for contentType.

This is copied when set.

pub unsafe fn minimumDimension(&self) -> CGFloat

Available on crate feature objc2-core-foundation only.

Defaults to 0. If set, the thumbnail will have a width and height greater or equal to minimumDimension * scale. If set and it is not possible to generate thumbnails of minimumDimension for any of the requested QLThumbnailGenerationRequestRepresentationTypes, no thumbnail will be provided.

pub unsafe fn setMinimumDimension(&self, minimum_dimension: CGFloat)

Available on crate feature objc2-core-foundation only.

Setter for minimumDimension.

pub unsafe fn iconMode(&self) -> bool

If set to YES, this will generate something appropriate for display as a file icon, meaning that the thumbnail might be embedded in a frame, show a curled corner, draw a background and/or a drop shadow, as appropriate for the platform. If set to NO, this will generate a raw undecorated thumbnail. Defaults to NO.

pub unsafe fn setIconMode(&self, icon_mode: bool)

Setter for iconMode.

pub unsafe fn size(&self) -> CGSize

Available on crate feature objc2-core-foundation only.
pub unsafe fn scale(&self) -> CGFloat

Available on crate feature objc2-core-foundation only.
pub unsafe fn representationTypes( &self, ) -> QLThumbnailGenerationRequestRepresentationTypes

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}